@@ -1,24 +1,16 @@
 package Helios::Error::Fatal;
 
-use 5.008;
-use strict;
-use warnings;
-use base qw(Helios::Error::BaseError);
-
-our $VERSION = '2.811_4150';
-
-# 2011-12-18:  Changed base class from Error::Simple to Helios::Error::BaseError.
-# [2014-10-10] [LH]: Added 5.008, strict, and warnings pragmas for Kwalitee 
-# ratings.
+use base qw(Error::Simple);
 
+our $VERSION = '1.20';
 
 1;
 __END__;
 
 =head1 NAME
 
-Helios::Error::Fatal - fatal exception class for Helios indicating a job failed
- but can be re-attempted
+Helios::Error::Fatal - fatal exception class for Helios job processing system; implies 
+a job failed but can be re-attempted
 
 =head1 SYNOPSIS
 
@@ -59,8 +51,7 @@ error is severe enough to prevent the system from re-attempting the job later.
 
 =head1 SEE ALSO
 
-L<Helios::Error::FatalNoRetry>, L<Helios::Error::Warning>, 
-L<Helios::Error::BaseError>, L<Error>, L<Error::Simple>
+L<Helios::Error::FatalNoRetry>, L<Helios::Error::Warning>, L<Error>, L<Error::Simple>
 
 =head1 AUTHOR
 
