@@ -6,44 +6,19 @@ use warnings;
 
 use DBI;
 use Error qw(:try);
-# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
-use Helios::TS;
-use Helios::TS::Job;
-use Helios::ObjectDriver::DBI;
-
+use TheSchwartz;
+use TheSchwartz::Job;
 require XML::Simple;
+$XML::Simple::PREFERRED_PARSER = 'XML::Parser';
 
 use Helios::Error;
 use Helios::JobHistory;
 
-our $VERSION = '2.801_3270';
+our $VERSION = '2.00';
 
 our $D_OD_RETRIES = 3;
 our $D_OD_RETRY_INTERVAL = 5;
 
-# 2011-12-15:  Removed setting $XML::Simple::PREFERRED_PARSER.
-# 2012-01-01:  Changed failed() and failedNoRetry() methods to truncate error 
-# string at 256 chars.  That's the max length of the matching field in the 
-# ERROR table.  Updated copyright info.
-# 2012-03-27:  Documented accessor methods and greatly expanded and updated 
-# JOB SUBMISSION documentation.
-# 2012-04-01:  Added setDriver() and initDriver() methods.  Refactored old 
-# getDriver() into initDriver(), and changed getDriver() to call initDriver().
-# 2012-04-25:  Added deferred() method.
-# [LH] 2012-07-11: submit(): changed to use Helios::TheSchwartz instead of 
-# base TheSchwartz to implement database connection caching.
-# [LH] [2013-09-07] new(): changed to check to see if TheSchwartz::Job object 
-# to new() has an array in arg(), and throw an exception if it doesn't.
-# (It always should, but [RT79690] is preventing that in a tiny number of cases.) 
-# [LH] [2013-10-18] Replaced calls to Helios::TheSchwartz and TheSchwartz::Job
-# with Helios::TS and Helios::TS::Job.
-# [LH] [2013-10-28] Added set/getArgString(), set/getJobType(), 
-# set/getJobtypeid() methods; set/getArgXML(), set/getFuncname(), 
-# set/getFuncid() will be deprecated in Helios 3.x.  Changed POD to document 
-# the new functions.  
-# [LH] [2014-08-10] Added get/setPriority() methods.
-
-
 =head1 NAME
 
 Helios::Job - base class for jobs in the Helios job processing system
@@ -54,35 +29,9 @@ Helios::Job is the standard representation of jobs in the Helios framework.  It
 related to the underlying TheSchwartz::Job objects, and provides its own methods for manipulating 
 jobs in the Helios system.
 
+
 =head1 ACCESSOR METHODS
 
-These accessors allow access to information about an instantiated Helios::Job 
-object:
-
- debug()             whether Debug Mode is enabled or not
- get/setConfig()     Helios configuration passed by the system to the job object
- get/setArgs()       hashref of the job's arguments (interpreted from the arg string)
- get/setArgString()  the raw XML of the job arguments
-
-Several accessors are pass-through accessors to access values in the 
-underlying TheSchwartz::Job object
- 
- get/setJobid()         jobid of the job in the job queue
- get/setFailures()      number of previous failures of the job before current run
- get/setJobtypeid()     jobtypeid value of the job 
- get/setJobType()       jobtype name of the job
- get/setUniqkey()       uniqkey value of the job (see TheSchwartz documentation)
- get/setRunAfter()      current run_after value of the job
- get/setGrabbedUntil()  current grabbed_until value of the job
- get/setCoalesce()      coalesce value of the job (see TheSchwartz documentation)
-
-When running a job, your service class need not access any of these values 
-directly, though the information is available if you need it (for example, 
-to log how many failures your job has encountered before the current run).  
-When submitting a job, several of the set* accessors are needed to set up the
-job before submission; see the section on the submit() method for more 
-information.
-
 =cut
 
 sub setConfig { $_[0]->{config} = $_[1]; }
@@ -115,47 +64,15 @@ sub getGrabbedUntil { return $_[0]->job()->grabbed_until; }
 sub setCoalesce { return $_[0]->job()->coalesce($_[1]); }
 sub getCoalesce { return $_[0]->job()->coalesce; }
 
-# BEGIN CODE Copyright (C) 2012 by Andrew Johnson.
-sub setDriver { $_[0]->{driver} = $_[1]; }
-sub getDriver { 
-	if ( defined($_[0]->{driver}) ) {
-		return $_[0]->{driver};
-	} else {
-		return $_[0]->initDriver();
-	}
-}
-# END CODE Copyright (C) 2012 by Andrew Johnson.
-
-sub debug { my $self = shift; @_ ? $self->{debug} = shift : $self->{debug}; }
-
 # these are for direct access to the underlying TheSchwartz::Job object
 sub job { my $self = shift; @_ ? $self->{job} = shift : $self->{job}; }
 
+
 sub setArgXML { $_[0]->{argxml} = $_[1]; }
 sub getArgXML { return $_[0]->{argxml}; }
 
-# BEGIN CODE Copyright (C) 2013 by Logical Helion, LLC.
-sub setArgString { setArgXML(@_) }
-sub getArgString { getArgXML(@_) }
+sub debug { my $self = shift; @_ ? $self->{debug} = shift : $self->{debug}; }
 
-sub setJobType { setFuncname(@_) }
-sub getJobType { getFuncname(@_) }
-
-sub setJobtypeid { setFuncid(@_) }
-sub getJobtypeid { getFuncid(@_) }
-# END CODE Copyright (C) 2013 by Logical Helion, LLC.
-
-# BEGIN CODE Copyright (C) 2014 by Logical Helion, LLC.
-sub setPriority {
-	my $self = shift;
-	my $p = shift;
-	$self->job()->priority($p);
-}
-sub getPriority {
-	my $self = shift;
-	$self->job()->priority();
-}
-# END CODE Copyright (C) 2014 by Logical Helion, LLC.
 
 =head1 METHODS
 
@@ -171,23 +88,10 @@ sub new {
 	bless $self, $class;
 
 	# init fields
-	# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
-	if ( defined($_[0]) && ref($_[0]) && $_[0]->isa('Helios::TS::Job') ) {
+	if ( defined($_[0]) && ref($_[0]) && $_[0]->isa('TheSchwartz::Job') ) {
 		$self->job($_[0]);
-# BEGIN CODE COPYRIGHT (C) 2013 LOGICAL HELION, LLC.
-# [LH] [2013-09-07] new(): changed to check to see if TheSchwartz::Job object 
-# to new() has an array in arg(), and throw an exception if it doesn't.
-# (It always should, but [RT79690] is preventing that in a tiny number of cases.) 
-		if ( ref($_[0]->arg()) eq 'ARRAY' ) {
-			my $arg_str = $_[0]->arg()->[0];
-			$self->setArgXML($arg_str);		
-		} else {
-			Helios::Error::DatabaseError->throw("Received job without actual job arguments, probably due to transient database problem [RT79690].");				
-		}
-# END CODE COPYRIGHT (C) 2013 LOGICAL HELION, LLC.
 	} else {
-		# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
-		my $schwartz_job = Helios::TS::Job->new(@_);
+		my $schwartz_job = TheSchwartz::Job->new(@_);
 		$self->job($schwartz_job);
 	}
 
@@ -382,7 +286,7 @@ sub failed {
             }
         };
 	}	
-	$job->failed(substr($error,0,254), $exitstatus);
+	$job->failed($error, $exitstatus);
 	return $exitstatus;
 }
 
@@ -439,35 +343,10 @@ sub failedNoRetry {
         };
 	}
 
-	$job->permanent_failure(substr($error,0,254), $exitstatus);
+	$job->permanent_failure($error, $exitstatus);
 	return $exitstatus;
 }
 
-=head2 deferred()
-
-Defers processing of a job even though it was available for processing in the 
-queue.  The job will be seen as available for processing again when the 
-grabbed_until time has expired (the default is 60 minutes).  If your service 
-employs the job retry API, a declined job run does not count against the job's 
-retry count.
-
-Unlike the completed() and failed*() methods above, deferred() is actually 
-only a wrapper around TheSchwartz 1.10's TheSchwartz::Job->declined() method 
-for now.  No job history is recorded in the HELIOS_JOB_HISTORY_TB in the 
-collective database.  This may change in the future.
-
-=cut
-
-sub deferred {
-	my $self = shift;
-	my $job = $self->job();
-
-	$job->declined();
-	return 0;
-}
-
-
-=head1 JOB SUBMISSION
 
 =head2 submit()
 
@@ -476,73 +355,11 @@ error if it fails.
 
 Before a job can be successfully submitted, the following must be set first:
 
- $job->setConfig($configHash);
- $job->setArgString($xmlstring);
- $job->setJobType($servicename);
+ $job->setConfig()
+ $job->setArgXML()
+ $job->setFuncname()
 
-So, for example, to submit a Helios::TestService to the Helios system, you need 
-to do the following:
 
- # you need Helios::Service and Helios::Job
- use Helios::Service;
- use Helios::Job;
-
- # these are the job arguments we want to pass to Helios::TestService
- my $jobxml = "<job><params><string1>This is a test</string1/params>/job>";
-
- # first, use Helios::Service to get the Helios configuration
- my $srv = Helios::Service->new();
- $srv->prep();
- my $config = $srv->getConfig();
- 
- # once you have the config, you can set up the Helios::Job
- my $job = Helios::Job->new();
- $job->setConfig($config);
- $job->setJobType('Helios::TestService');
- $job->setArgString($jobxml);
- 
- # then submit the job (this will throw an exception if something goes wrong)
- my $jobid = $job->submit();
- print "Submitted job $jobid to Helios\n";
- 
-Both Helios::Service->prep() and Helios::Job->submit() will throw exceptions 
-if they encounter errors, so a safer example would catch them:
-
- use Helios::Service;
- use Helios::Job;
-
- my $jobxml = "<job><params><string1>This is a test</string1/params>/job>";
-
- my $srv = Helios::Service->new();
- eval {
- 	$srv->prep();
- 	1;
- } or do {
- 	my $E = $@;
- 	print "Error encountered prepping Helios service: $E\n";
- 	exit(1);
- };
- my $config = $srv->getConfig();
- 
- # once you have the config, you can set up the Helios::Job
- my $job = Helios::Job->new();
- $job->setConfig($config);
- $job->setJobType('Helios::TestService');
- $job->setArgString($jobxml);
- 
- # then submit the job (this will throw an exception if something goes wrong)
- my $jobid;
- eval {
-	$jobid = $job->submit();
- 	1;
- } or do {
-	my $E = $@;
-	print "Error encountered attempting job submission: $E\n"; 	
- };
- print "Submitted job $jobid to Helios\n";
-
-Of course, the Try::Tiny (available on CPAN) would work just as well as an
-eval{} block, and have much prettier syntax.
 
 =cut
 
@@ -561,8 +378,7 @@ sub submit {
 
 	my $args = [ $params ];
 
-	# [LH] [2013-10-18] Replaced Helios::TheSchwartz with Helios::TS
-	my Helios::TS $client = Helios::TS->new( databases => $databases, verbose => 1 );
+	my $client = TheSchwartz->new( databases => $databases, verbose => 1 );
 	my $sjh = $client->insert($job_class, $args);
 	$self->setJobid($sjh->jobid);
 	return $sjh->jobid;
@@ -638,28 +454,26 @@ sub burst {
 
 =head1 OTHER METHODS
 
-=head2 initDriver()
+=head2 getDriver()
 
 Returns a Data::ObjectDriver object for use with Helios layer database updates.
 
 =cut
 
-# BEGIN CODE Copyright (C) 2012 by Andrew Johnson.
-
-sub initDriver {
+sub getDriver {
 	my $self = shift;
 	my $config = $self->getConfig();
 	if ($self->debug) { print $config->{dsn},$config->{user},$config->{password},"\n"; }
-	my $driver = Helios::ObjectDriver::DBI->new(
+	my $driver = Data::ObjectDriver::Driver::DBI->new(
 	    dsn      => $config->{dsn},
 	    username => $config->{user},
 	    password => $config->{password}
 	);	
-	if ($self->debug) { print 'Job->initDriver() DRIVER: ',$driver,"\n"; }
-	$self->setDriver($driver);
+	if ($self->debug) { print "DRIVER: ",$driver,"\n"; }
 	return $driver;	
 }
-# END CODE Copyright (C) 2012 by Andrew Johnson.
+
+
 
 
 1;
@@ -668,22 +482,16 @@ __END__
 
 =head1 SEE ALSO
 
-L<Helios::Service>, L<Helios::TS>, L<Helios::TS::Job>, L<XML::Simple>
+L<Helios::Service>, L<Helios::Error>, L<TheSchwartz::Job>, L<XML::Simple>, L<Config::IniFiles>
 
 =head1 AUTHOR
 
-Andrew Johnson, E<lt>lajandy at cpan dotorgE<gt>
+Andrew Johnson, E<lt>ajohnson@ittoolbox.comE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2008 by CEB Toolbox, Inc.
 
-Portions of this software, where noted, are
-Copyright (C) 2012 by Andrew Johnson.
-
-Portions of this software, where noted, are
-Copyright (C) 2013-4 by Logical Helion, LLC.
-
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.0 or,
 at your option, any later version of Perl 5 you may have available.
